<!-- SPDX-License-Identifier: CC-BY-4.0 -->
<!-- Copyright Contributors to the Egeria project. -->

# Catalog User

These widgets display different kinds of information useful to a typical catalog user. Widgets
will continue to be added over time to cover more facets of catalog use. 

* list_assets.py - lists assets containing the user provided search string in the display name or qualified name. Search string must be a minimum of three characters.
* view_asset_graph.py - shows a tree view of an asset with its nested elements and relationships.
* view_collection.py - provides a tree view of a collection with all nested collections and items within the collection.
* view_glossary.py - provides a simple glossary viewer showing terms and related information. 
* get_asset_graph.py - shows an asset with all its relationships as a tree graph.
----
License: [CC BY 4.0](https://creativecommons.org/licenses/by/4.0/),
Copyright Contributors to the Egeria project.